Index: include/lib/gfx.h |
diff --git a/include/lib/gfx.h b/include/lib/gfx.h |
index 8c68daa8701921f47ef5dba078e54ba3fcac9993..ca5c3797bed2c5f315ce9d30759cc233d1f04fe2 100644 |
--- a/include/lib/gfx.h |
+++ b/include/lib/gfx.h |
@@ -103,9 +103,9 @@ void gfx_flush_rows(struct gfx_surface *surface, uint start, uint end); |
// surface setup |
gfx_surface *gfx_create_surface(void *ptr, uint width, uint height, uint stride, gfx_format format); |
-// utility routine to make a surface out of a display info |
-struct display_info; |
-gfx_surface *gfx_create_surface_from_display(struct display_info *); |
+// utility routine to make a surface out of a display framebuffer |
+struct display_framebuffer; |
+gfx_surface *gfx_create_surface_from_display(struct display_framebuffer *) __NONNULL((1)); |
// free the surface |
// optionally frees the buffer if the free bit is set |